import { ChartCompType } from "./lib/Table2Chart/const/chartCompType.ts";
import { mapHeight, mapWidth } from "./lib/Table2Chart/funcs/mapGEOStyle.ts";

const sampleForLineCharts = {
  type: ChartCompType.EChartsBar,
  category: ["Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun"],
  data: [120, 200, 150, 80, 70, 110, 130],
};

const sampleForRadarCharts = {
  type: ChartCompType.SimpleRadar,
  indicators: [
    { name: 'Sales', max: 6500, min: 0 },
    { name: 'Administration', max: 16000, min: 0 },
    { name: 'Information Technology', max: 30000, min: 0 },
    { name: 'Customer Support', max: 38000, min: 0 },
    { name: 'Development', max: 52000, min: 0 },
    { name: 'Marketing', max: 25000, min: 0 }
  ],
  data: [
    {
      value: [4200, 3000, 20000, 35000, 50000, 18000],
      name: 'Allocated Budget'
    },
    {
      value: [5000, 14000, 28000, 26000, 42000, 21000],
      name: 'Actual Spending'
    }
  ]
}

const sampleForVerLineCharts = {
  type: ChartCompType.SimpleLine,
  category: ["Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun"],
  data: [
    { name: "测试1", data: [120, 200, 150, 80, 70, 110, 130] },
    { name: "测试2", data: [100, 100, 110, 10, 10, 100, 100] },
  ],
};

const sampleKLine = {
  type: ChartCompType.DIY,
  options: {
    xAxis: {
      data: ['2017-10-24', '2017-10-25', '2017-10-26', '2017-10-27']
    },
    yAxis: {},
    tooltip: {
      trigger: "axis",
      axisPointer: {
        type: "shadow",
      },
      appendTo: 'body'
    },
    grid: {
      left: "3%",
      right: "4%",
      bottom: "3%",
      containLabel: true,
      top: "5%",
    },
    series: [
      {
        type: 'candlestick',
        data: [
          [20, 34, 10, 38],
          [40, 35, 30, 50],
          [31, 38, 33, 44],
          [38, 15, 5, 42]
        ]
      }
    ]
  },
  onClickGraph(item: any, index: number) {
    alert('click-kline')
    console.log('item-here', {item, index})
  }
}

const sampleScatter = {
  type: ChartCompType.DIY,
  options: {
    xAxis: {},
    yAxis: {},
    tooltip: {
      trigger: "axis",
      axisPointer: {
        type: "shadow",
      },
      appendTo: 'body'
    },
    grid: {
      left: "3%",
      right: "4%",
      bottom: "3%",
      containLabel: true,
      top: "5%",
    },
    series: [
      {
        symbolSize: 20,
        data: [
          [10.0, 8.04],
          [8.07, 6.95],
          [13.0, 7.58],
          [9.05, 8.81],
          [11.0, 8.33],
          [14.0, 7.66],
          [13.4, 6.81],
          [10.0, 6.33],
          [14.0, 8.96],
          [12.5, 6.82],
          [9.15, 7.2],
          [11.5, 7.2],
          [3.03, 4.23],
          [12.2, 7.83],
          [2.02, 4.47],
          [1.05, 3.33],
          [4.05, 4.96],
          [6.03, 7.24],
          [12.0, 6.26],
          [12.0, 8.84],
          [7.08, 5.82],
          [5.02, 5.68]
        ],
        type: 'scatter'
      }
    ]
  },
  onClickGraph(item: any, index: number) {
    alert('click-scatter!')
    console.log('item-here', {item, index})
  }
}

const bottomCenterTextCharts = {
  title: "奇特上下排位图表",
  columns: 4,
  chartData: Array(12)
    .fill(2)
    .map(() => ({
      type: ChartCompType.EchartsPieBottomCenterText,
      radius: ["60%", "90%"],
      chartWidth: () => mapWidth(120),
      chartHeight: () => mapHeight(120),
      title: "示例图表",
      data: [
        { name: "类型一", color: "#ffaacc", value: 100 },
        { name: "类型二", color: "#abc001", value: 200 },
        { name: "类型三", color: "#cad13c", value: 50 },
      ],
      bottomText: "奇特数据呢!",
    })),
};

const indexMapper: Record<string, any> = {
  7: bottomCenterTextCharts,
  3: {
    title: "简单数字内容显示",
    columns: 2,
    chartData: Array(2)
      .fill(1)
      .map(() => ({
        title: 15,
        bottomText: "奇特数据",
        type: ChartCompType.BottomCenterText,
      })),
  },
  2: {
    title: "混编数据",
    columns: 2,
    chartData: [
      {
        type: ChartCompType.BottomCenterText,
        title: 100,
        bottomText: "奇特数据",
      },
      {
        type: ChartCompType.EChartsPieCenterText,
        radius: ["60%", "90%"],
        title: "示例图表",
        data: [
          { name: "类型一", color: "#ffaacc", value: 100 },
          { name: "类型二", color: "#abc001", value: 200 },
          { name: "类型三", color: "#cad13c", value: 50 },
        ],
      },
    ],
  },
  4: {
    title: "简单混排图",
    chartData: [sampleForLineCharts, sampleForLineCharts],
  },
  0: {
    title: "简单折线图",
    chartData: [sampleForVerLineCharts, sampleForVerLineCharts],
  },
  5: {
    title: "啊哈哈表格呢",
    columns: 1,
    chartData: [
      {
        type: ChartCompType.SimpleTable,
        columns: [
          { key: "a", title: "种类一" },
          { key: "b", title: "种类二" },
          { key: "c", title: "中类似" },
          { key: "d", title: "奇特呢" },
        ],
        data: Array(20)
          .fill(1)
          .map(() => {
            return {
              a: 12,
              b: 123,
              c: 434,
              d: 3123,
            };
          }),
      },
    ],
  },
  1: {
    title: "随意设置图",
    chartData: [sampleKLine, sampleScatter],
    onClickTitle(item: any) {
      alert('click-random')
      console.log('item-here', {item})
    }
  },
  6: {
    title: "简单混排图",
    chartData: [sampleForLineCharts, sampleForRadarCharts],
  },
};

const layout = [
  { x: 0, y: 0, w: 4, h: 1 },
  { x: 4, y: 0, w: 8, h: 1 },
  { x: 0, y: 2, w: 2, h: 1 },
  { x: 2, y: 2, w: 2, h: 1 },
  { x: 4, y: 2, w: 3, h: 1 },
  { x: 7, y: 1, w: 5, h: 4 },
  { x: 0, y: 1, w: 7, h: 1 },
  { x: 0, y: 3, w: 7, h: 2 },
].map((a, q) => ({
  ...a,
  ...indexMapper[q],
}));

export { layout };
