import {Directive, DirectiveBinding, ref} from 'vue';
import gsap from 'gsap';

interface NumberAnimationOptions {
    value?: number;
    decimals?: number;
    ease?: string;
    formatter?: (value: number) => string;
}

type NumberAnimationBinding = number | NumberAnimationOptions;

export const vNumberAnimation: Directive = {
    mounted(el: HTMLElement, binding: DirectiveBinding<NumberAnimationBinding>) {
        const target = ref(0);
        const duration = parseFloat(binding.arg as string) || 1;
        const options = typeof binding.value === 'number'
            ? { value: binding.value }
            : binding.value || {};

        el.textContent = target.value.toString();
        // @ts-ignore
        el._animation = gsap.to(target, {
            value: options.value || parseFloat(el.dataset.value || '0'),
            duration,
            ease: options.ease || 'power1.out',
            onUpdate: () => {
                el.textContent = options.formatter
                    ? options.formatter(target.value)
                    : target.value.toFixed(options.decimals || 0);
            }
        });
    },

    updated(el: HTMLElement, binding: DirectiveBinding<NumberAnimationBinding>) {
        // @ts-ignore
        if (el._animation) {
            // @ts-ignore
            el._animation.kill();
        }

        // @ts-ignore
        const target = ref(parseFloat(el.textContent));
        const duration = parseFloat(binding.arg as string) || 1;
        const options = typeof binding.value === 'number'
            ? { value: binding.value }
            : binding.value || {};

        // @ts-ignore
        el._animation = gsap.to(target, {
            value: options.value || parseFloat(el.dataset.value || '0'),
            duration,
            ease: options.ease || 'power1.out',
            onUpdate: () => {
                el.textContent = options.formatter
                    ? options.formatter(target.value)
                    : target.value.toFixed(options.decimals || 0);
            }
        });
    },

    unmounted(el: HTMLElement) {
        // @ts-ignore
        if (el._animation) {
            // @ts-ignore
            el._animation.kill();
        }
    }
};