import {
  BarChartOptions,
  DIYChart,
  GeneralChartOptions,
  LineChartOptions,
  PieCharOptions,
  SimpleRadarChart
} from "../types/ScreenChart.typing.ts";
import {ChartCompType} from "../const/chartCompType.ts";
import {baseEchartOptions} from "../const/staticConsts.ts";

export function mapToEchartsOptions(item: GeneralChartOptions) {
    if (item.type === ChartCompType.DIY) {
        item = <DIYChart>item;
        return item.options;
    }
    if (item.type === ChartCompType.SimpleLine) {
        let series: any[];
        item = <LineChartOptions>item;
        if (item.data.every((a) => typeof a === "number")) {
            series = [{data: item.data, type: "line"}];
        } else {
            series = item.data.map((a) => {
                return {
                    type: "line",
                    name: a.name,
                    data: a.data,
                };
            });
        }
        return {
            ...baseEchartOptions(item),
            series,
        };
    }
    if (item.type === ChartCompType.EChartsBar) {
        let series: any[];
        // 简单类型数据
        item = <BarChartOptions>item;
        if (item.data.every((a) => typeof a === "number")) {
            series = [{data: item.data, type: "bar"}];
        } else {
            series = item.data.map((a) => {
                return {
                    type: "bar",
                    name: a.name,
                    data: a.data,
                };
            });
        }
        return {
            ...baseEchartOptions(item),
            series,
        };
    }
    if (
        item.type === ChartCompType.EChartsPieCenterText ||
        item.type === ChartCompType.EchartsPieBottomCenterText
    ) {
        item = <PieCharOptions>item;
        const total = item.data.reduce((a, b) => a + b.value, 0);
        return {
            grid: {
                left: 0,
                right: 0,
                bottom: 0,
                containLabel: true,
                top: 0,
            },
            series: [
                {
                    radius: item.radius || undefined,
                    type: "pie",
                    center: ["50%", "50%"],
                    avoidLabelOverlap: false,
                    emphasis: {
                        scaleSize: 3,
                    },
                    label: {
                        show: false,
                    },
                    labelLine: {
                        show: false,
                    },
                    data: item.data.map(function (item) {
                        return {
                            value: item.value,
                            name: item.name,
                            itemStyle: {
                                color: item.color,
                            },
                        };
                    }),
                },
            ],
            toolbox: false,
            legend: item.legend || undefined,
            tooltip: {
                trigger: "item",
                formatter: function (param: any) {
                    return `${param.name}：${
                        total ? ((param.value * 100) / total).toFixed(2) : 100
                    }% ${param.value}`;
                },
                showDelay: 0,
                hideDelay: 0,
                extraCssText: "pointer-events: none;",
                position: "top",
                appendTo: "body",
            },
        };
    }
    if (item.type === ChartCompType.SimpleRadar) {
        item = <SimpleRadarChart>item;
        return {
            ...baseEchartOptions(item),
            xAxis: null,
            yAxis: null,
            tooltip: {
                trigger: 'item',
                appendTo: 'body'
            },
            radar: {
                indicator: item.indicators || [],
            },
            legend: item.legend || undefined,
            series: [
                {
                    type: 'radar',
                    data: item.data,
                    areaStyle: {
                        color: 'rgb(188, 217, 251)' // 设置填充颜色
                    },
                    symbol: 'none', // 不显示圆点
                    symbolSize: 0 // 圆点大小设置为0
                }
            ]
        }
    }
}
