import { VNode } from "vue";
import { ChartCompType } from "../const/chartCompType.ts";

export type BarChartOptions = {
  category: string[];
  data: number[] | { name: string; data: number[] }[];
  type: ChartCompType;
  chartWidth?: number | string;
  chartHeight?: number | string;
  options?: any
  onClickGraph?: Function;
};

export type LineChartOptions = BarChartOptions;

export type PieChartOptionsBase = {
  type: ChartCompType;
  radius: Array<string>;
  data: Array<{ value: number; name: string; color: string }>;
  chartWidth?: number | string;
  chartHeight?: number | string;
  legend?: any;
  options?: any
  onClickGraph?: Function;
};

export type PieCharOptions = PieChartOptionsBase & {
  title: string;
};

export type PieCharOptionsForBottomCenterText = PieCharOptions & {
  bottomText: string;
};

export type ButtonCenterText = {
  title: string;
  bottomTex: string;
  type: ChartCompType;
  onClickGraph?: Function;
};

export type SimpleTableChart = {
  type: ChartCompType;
  columns: Array<{ title: string; key: string }>;
  data: Array<Record<string, any>>;
  options?: any
  onClickGraph?: Function;
};

export type SimpleRadarChart = {
  type: ChartCompType;
  data: Array<{
    name: string;
    value: number[];
  }>;
  legend?: any;
  indicators: Array<{ name: string; max: number }>;
  options?: any
  onClickGraph?: Function;
};

export type DIYChart = {
  type: ChartCompType.DIY,
  options: any,
  chartWidth?: number | string;
  chartHeight?: number | string;
  onClickGraph?: Function;
}

export type GeneralChartOptions =
  | BarChartOptions
  | PieCharOptions
  | PieCharOptionsForBottomCenterText
  | ButtonCenterText
  | SimpleTableChart
  | LineChartOptions | SimpleRadarChart | DIYChart;

export type ChartOptionSet = Array<GeneralChartOptions>;

export type SingleLayoutConf = {
  x: number;
  y: number;
  w: number;
  h: number;
  title: string;
  renderTitle?: (...args: any[]) => VNode;
  chartData: ChartOptionSet;
  wrapperClass?: string | Array<string> | Record<string, any>;
  wrapperStyle?: Record<string, any> | Function;
  columns?: number;
  onClickTitle?: Function;
};

export type LayoutConfig = Array<SingleLayoutConf>;

export type ScreenChartProps = {
  layout: LayoutConfig;
  gap?: number;
  containerPadding?: number;
  gridItemPadding?: number;
};
